pub struct Icon {
pub props: Props,
/* private fields */
}Fields
props: PropsTrait Implementations
Sourceimpl ComponentExt for Icon
impl ComponentExt for Icon
Sourcefn set_visible(&self, visible: bool)
fn set_visible(&self, visible: bool)
Set the visibility of this component.
Sourcefn set_styles(&self, styles: Vec<Style>)
fn set_styles(&self, styles: Vec<Style>)
Set the
crate::styles::Styles of this component. Read moreSourcefn remove_class(&self, class: &str)
fn remove_class(&self, class: &str)
Remove a CSS from this component.
Sourcefn props(&self) -> &dyn ExtendingProps
fn props(&self) -> &dyn ExtendingProps
Get the props of this component.
Sourcefn annotations<'a>(&'a self) -> Ref<'a, Annotations>
fn annotations<'a>(&'a self) -> Ref<'a, Annotations>
Get the annotations of this component.
Sourcefn annotations_mut<'a>(&'a self) -> RefMut<'a, Annotations>
fn annotations_mut<'a>(&'a self) -> RefMut<'a, Annotations>
Get a mutable ref to the annotations of this component.
Sourcefn try_annotations_mut<'a>(
&'a self,
) -> Result<RefMut<'a, Annotations>, BorrowMutError>
fn try_annotations_mut<'a>( &'a self, ) -> Result<RefMut<'a, Annotations>, BorrowMutError>
Like
annotations_mut but with a Result. Errors when the annotations can not be borrowed mutably.Auto Trait Implementations
impl !Freeze for Icon
impl !RefUnwindSafe for Icon
impl !Send for Icon
impl !Sync for Icon
impl Unpin for Icon
impl !UnwindSafe for Icon